@@ -3,12 +3,12 @@
 /** 
  * Version of liboqs as a string. Equivalent to {MAJOR}.{MINOR}.{PATCH}{PRE_RELEASE} 
  */
-#define OQS_VERSION_TEXT "0.14.0"
+#define OQS_VERSION_TEXT "0.15.0"
 /** 
  * Version levels of liboqs as integers.
  */
 #define OQS_VERSION_MAJOR 0
-#define OQS_VERSION_MINOR 14
+#define OQS_VERSION_MINOR 15
 #define OQS_VERSION_PATCH 0
 /** 
  * OQS_VERSION_PRE_RELEASE is defined if this is a pre-release version of liboqs, otherwise it is undefined.
@@ -16,7 +16,7 @@
  */
 /* #undef OQS_VERSION_PRE_RELEASE */
 
-#define OQS_COMPILE_BUILD_TARGET "ARM64-Windows-6.2.9200"
+#define OQS_COMPILE_BUILD_TARGET "ARM64-Windows-10.0.26200"
 #define OQS_DIST_BUILD 1
 /* #undef OQS_DIST_X86_64_BUILD */
 /* #undef OQS_DIST_X86_BUILD */
@@ -72,6 +72,7 @@
 /* #undef OQS_USE_SHA3_AVX512VL */
 
 #define OQS_USE_CUPQC 0
+#define OQS_USE_ICICLE 0
 
 /* #undef OQS_ENABLE_KEM_BIKE */
 /* #undef OQS_ENABLE_KEM_bike_l1 */
@@ -90,6 +91,18 @@
 #define OQS_ENABLE_KEM_ntruprime_sntrup761 1
 /* #undef OQS_ENABLE_KEM_ntruprime_sntrup761_avx2 */
 
+#define OQS_ENABLE_KEM_NTRU 1
+#define OQS_ENABLE_KEM_ntru_hps2048509 1
+/* #undef OQS_ENABLE_KEM_ntru_hps2048509_avx2 */
+#define OQS_ENABLE_KEM_ntru_hps2048677 1
+/* #undef OQS_ENABLE_KEM_ntru_hps2048677_avx2 */
+#define OQS_ENABLE_KEM_ntru_hps4096821 1
+/* #undef OQS_ENABLE_KEM_ntru_hps4096821_avx2 */
+#define OQS_ENABLE_KEM_ntru_hps40961229 1
+#define OQS_ENABLE_KEM_ntru_hrss701 1
+/* #undef OQS_ENABLE_KEM_ntru_hrss701_avx2 */
+#define OQS_ENABLE_KEM_ntru_hrss1373 1
+
 ///// OQS_COPY_FROM_UPSTREAM_FRAGMENT_ADD_ALG_ENABLE_DEFINES_START
 
 #define OQS_ENABLE_KEM_CLASSIC_MCELIECE 1
@@ -135,25 +148,17 @@
 /* #undef OQS_ENABLE_KEM_ml_kem_512_x86_64 */
 /* #undef OQS_ENABLE_KEM_ml_kem_512_aarch64 */
 /* #undef OQS_ENABLE_KEM_ml_kem_512_cuda */
+/* #undef OQS_ENABLE_KEM_ml_kem_512_icicle_cuda */
 #define OQS_ENABLE_KEM_ml_kem_768 1
 /* #undef OQS_ENABLE_KEM_ml_kem_768_x86_64 */
 /* #undef OQS_ENABLE_KEM_ml_kem_768_aarch64 */
 /* #undef OQS_ENABLE_KEM_ml_kem_768_cuda */
+/* #undef OQS_ENABLE_KEM_ml_kem_768_icicle_cuda */
 #define OQS_ENABLE_KEM_ml_kem_1024 1
 /* #undef OQS_ENABLE_KEM_ml_kem_1024_x86_64 */
 /* #undef OQS_ENABLE_KEM_ml_kem_1024_aarch64 */
 /* #undef OQS_ENABLE_KEM_ml_kem_1024_cuda */
-
-#define OQS_ENABLE_SIG_DILITHIUM 1
-#define OQS_ENABLE_SIG_dilithium_2 1
-/* #undef OQS_ENABLE_SIG_dilithium_2_avx2 */
-/* #undef OQS_ENABLE_SIG_dilithium_2_aarch64 */
-#define OQS_ENABLE_SIG_dilithium_3 1
-/* #undef OQS_ENABLE_SIG_dilithium_3_avx2 */
-/* #undef OQS_ENABLE_SIG_dilithium_3_aarch64 */
-#define OQS_ENABLE_SIG_dilithium_5 1
-/* #undef OQS_ENABLE_SIG_dilithium_5_avx2 */
-/* #undef OQS_ENABLE_SIG_dilithium_5_aarch64 */
+/* #undef OQS_ENABLE_KEM_ml_kem_1024_icicle_cuda */
 
 #define OQS_ENABLE_SIG_ML_DSA 1
 #define OQS_ENABLE_SIG_ml_dsa_44 1
@@ -331,6 +336,165 @@
 /* #undef OQS_ENABLE_SIG_snova_SNOVA_29_6_5_avx2 */
 /* #undef OQS_ENABLE_SIG_snova_SNOVA_29_6_5_neon */
 ///// OQS_COPY_FROM_UPSTREAM_FRAGMENT_ADD_ALG_ENABLE_DEFINES_END
+///// OQS_COPY_FROM_SLH_DSA_FRAGMENT_ADD_ALG_ENABLE_DEFINES_START
+#define OQS_ENABLE_SIG_SLH_DSA 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_pure_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_224_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_256_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_384_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_224_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha2_512_256_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_224_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_256_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_384_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_sha3_512_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_128_prehash_shake_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_sha2_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_sha2_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_sha2_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_sha2_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_sha2_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_sha2_256f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_shake_128s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_shake_128f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_shake_192s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_shake_192f 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_shake_256s 1
+#define OQS_ENABLE_SIG_slh_dsa_shake_256_prehash_shake_256f 1
+///// OQS_COPY_FROM_SLH_DSA_FRAGMENT_ADD_ALG_ENABLE_DEFINES_END
 
 ///// OQS_COPY_FROM_LIBJADE_FRAGMENT_ADD_ALG_ENABLE_DEFINES_START
 
@@ -396,8 +560,29 @@
 /* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h15_w1 */
 /* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h15_w2 */
 /* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h15_w4 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h15_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h20_w1 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h20_w2 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h20_w4 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h20_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h25_w1 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h25_w2 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h25_w4 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h25_w8 */
 /* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h5_w8_h5_w8 */
 /* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h10_w4_h5_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h10_w8_h5_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h10_w2_h10_w2 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h10_w4_h10_w4 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h10_w8_h10_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h15_w8_h5_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h15_w8_h10_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h15_w8_h15_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h20_w8_h5_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h20_w8_h10_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h20_w8_h15_w8 */
+/* #undef OQS_ENABLE_SIG_STFL_lms_sha256_h20_w8_h20_w8 */
+
 
 /* #undef OQS_HAZARDOUS_EXPERIMENTAL_ENABLE_SIG_STFL_KEY_SIG_GEN */
 /* #undef OQS_ALLOW_STFL_KEY_AND_SIG_GEN */
